aboutsummaryrefslogtreecommitdiffstats
path: root/components/script_traits/script_msg.rs
diff options
context:
space:
mode:
authorConnor Brewster <brewsterc@my.caspercollege.edu>2016-06-07 22:09:45 -0600
committerConnor Brewster <connor.brewster@eagles.oc.edu>2016-07-21 20:51:38 -0600
commitf13181876317c5d2e690dc4d0a5d10185eda1101 (patch)
tree070202b024ea55017ddb2ccc87d27eb44c9a9149 /components/script_traits/script_msg.rs
parent4ae0897175143351439ff5b903d05a79c17e3725 (diff)
downloadservo-f13181876317c5d2e690dc4d0a5d10185eda1101.tar.gz
servo-f13181876317c5d2e690dc4d0a5d10185eda1101.zip
Implement beginnings of joint session history
Fix backward navigation make use of history iterator Add frame iterator add different back logic cleanup navigation_info Add extra explanation for iter logic Remove forward history on full frame tree Rename navigation to traversal where appropriate check full tree for can go back/forward simplify frame iter logic remove FrameIterator cleanup history iter reduce amount of vec allocations removed extra parenthesis Remove history iterator cleanup after rebasing avoid recursive vec allocation remove full_frame_tree remove_forward_history_in_frame_tree -> clear_joint_session_future
Diffstat (limited to 'components/script_traits/script_msg.rs')
-rw-r--r--components/script_traits/script_msg.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/components/script_traits/script_msg.rs b/components/script_traits/script_msg.rs
index db92a143df5..3ba4494432b 100644
--- a/components/script_traits/script_msg.rs
+++ b/components/script_traits/script_msg.rs
@@ -17,7 +17,7 @@ use euclid::size::Size2D;
use gfx_traits::LayerId;
use ipc_channel::ipc::IpcSender;
use msg::constellation_msg::{Key, KeyModifiers, KeyState, LoadData};
-use msg::constellation_msg::{NavigationDirection, PipelineId, SubpageId};
+use msg::constellation_msg::{PipelineId, SubpageId, TraversalDirection};
use net_traits::CoreResourceMsg;
use offscreen_gl_context::{GLContextAttributes, GLLimits};
use style_traits::cursor::Cursor;
@@ -91,8 +91,8 @@ pub enum ScriptMsg {
/// Dispatch a mozbrowser event to a given iframe,
/// or to the window if no subpage id is provided.
MozBrowserEvent(PipelineId, Option<SubpageId>, MozBrowserEvent),
- /// HTMLIFrameElement Forward or Back navigation.
- Navigate(Option<(PipelineId, SubpageId)>, NavigationDirection),
+ /// HTMLIFrameElement Forward or Back traversal.
+ TraverseHistory(Option<PipelineId>, TraversalDirection),
/// Favicon detected
NewFavicon(Url),
/// Status message to be displayed in the chrome, eg. a link URL on mouseover.